@@ -27,7 +27,7 @@ KIND = 'veth'
 
 
 def port_bind(endpoint_id, port, subnets, network=None, vm_port=None,
-              segmentation_id=None):
+              segmentation_id=None, **kwargs):
     """Binds the Neutron port to the network interface on the host.
 
     :param endpoint_id:   the ID of the endpoint as string
@@ -37,11 +37,12 @@ def port_bind(endpoint_id, port, subnets, network=None, vm_port=None,
                          endpoint is trying to join
     :param network:      the Neutron network which the endpoint is trying to
                          join
-    :param vm_port:      the Nova instance dictionary, as returned by
+    :param vm_port:      the Nova instance port dictionary, as returned by
                          python-neutronclient. Container port under binding is
                          running inside this instance (either ipvlan/macvlan or
                          a subport)
     :param segmentation_id: ID of the segment for container traffic isolation)
+    :param kwargs:       Additional driver-specific arguments
     :returns: the tuple of the names of the veth pair and the tuple of stdout
               and stderr returned by processutils.execute invoked with the
               executable script for binding
@@ -84,11 +85,12 @@ def port_bind(endpoint_id, port, subnets, network=None, vm_port=None,
     return host_ifname, container_ifname, (stdout, stderr)
 
 
-def port_unbind(endpoint_id, neutron_port):
+def port_unbind(endpoint_id, neutron_port, **kwargs):
     """Unbinds the Neutron port from the network interface on the host.
 
     :param endpoint_id: the ID of the Docker container as string
     :param neutron_port: a port dictionary returned from python-neutronclient
+    :param kwargs:       Additional driver-specific arguments
     :returns: the tuple of stdout and stderr returned by processutils.execute
               invoked with the executable script for unbinding
     :raises: processutils.ProcessExecutionError, pyroute2.NetlinkError
